'use strict';

var core = require('@shikijs/core');
var engineJavascript = require('@shikijs/engine-javascript');
var React = require('react');
var javascript = require('../src/langs/javascript');
var php = require('../src/langs/php');
var tsx = require('../src/langs/tsx');
var typescript = require('../src/langs/typescript');

function _interopNamespaceDefaultOnly (e) { return Object.freeze({ __proto__: null, default: e }); }

var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
const ShikiContext = React.createContext({ highlighter: null, isReady: false });
const ShikiProvider = ({ children }) => {
  const [highlighter, setHighlighter] = React.useState(null);
  const [isReady, setIsReady] = React.useState(false);
  React.useEffect(() => {
    function setupHighlighter() {
      return __async(this, null, function* () {
        try {
          const highlighter2 = yield core.createHighlighterCore({
            langs: [javascript, typescript, tsx, php],
            // @ts-expect-error - Shiki types are incomplete
            themes: [Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespaceDefaultOnly(require('../node_modules/tm-themes/themes/github-dark.json.js')); })],
            engine: engineJavascript.createJavaScriptRegexEngine()
          });
          setHighlighter(highlighter2);
          setIsReady(true);
        } catch (error) {
          console.error("Error initializing Shiki highlighter:", error);
        }
      });
    }
    setupHighlighter();
  }, []);
  const contextValue = React.useMemo(() => ({ highlighter, isReady }), [highlighter, isReady]);
  if (!isReady) {
    return null;
  }
  return /* @__PURE__ */ React.createElement(ShikiContext.Provider, { value: contextValue }, children);
};
function useShiki() {
  return React.useContext(ShikiContext);
}

exports.ShikiProvider = ShikiProvider;
exports.useShiki = useShiki;
//# sourceMappingURL=SyntaxContext.js.map
