import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import React, { createContext, useState, useEffect, useContext } from 'react';
import javascript from '../src/langs/javascript';
import php from '../src/langs/php';
import tsx from '../src/langs/tsx';
import typescript from '../src/langs/typescript';

var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
const ShikiContext = createContext({ highlighter: null, isReady: false });
const ShikiProvider = ({ children }) => {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  useEffect(() => {
    function setupHighlighter() {
      return __async(this, null, function* () {
        try {
          const highlighter2 = yield createHighlighterCore({
            langs: [javascript, typescript, tsx, php],
            // @ts-expect-error - Shiki types are incomplete
            themes: [import('../node_modules/tm-themes/themes/github-dark.json.js')],
            engine: createJavaScriptRegexEngine()
          });
          setHighlighter(highlighter2);
          setIsReady(true);
        } catch (error) {
          console.error("Error initializing Shiki highlighter:", error);
        }
      });
    }
    setupHighlighter();
  }, []);
  const contextValue = React.useMemo(() => ({ highlighter, isReady }), [highlighter, isReady]);
  if (!isReady) {
    return null;
  }
  return /* @__PURE__ */ React.createElement(ShikiContext.Provider, { value: contextValue }, children);
};
function useShiki() {
  return useContext(ShikiContext);
}

export { ShikiProvider, useShiki };
//# sourceMappingURL=SyntaxContext.js.map
