import type { HighlighterCore } from '@shikijs/types'
import { createHighlighterCore } from '@shikijs/core'
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript'
import React, { createContext, useContext, useEffect, useState } from 'react'
import javascript from '../langs/javascript'
import php from '../langs/php'
import tsx from '../langs/tsx'
import typescript from '../langs/typescript'

const ShikiContext = createContext<{ highlighter: HighlighterCore | null, isReady: boolean }>({ highlighter: null, isReady: false })

const ShikiProvider: React.FC<{ children: React.ReactNode }> = ({ children }) => {
  const [highlighter, setHighlighter] = useState<HighlighterCore | null>(null)
  const [isReady, setIsReady] = useState(false)

  useEffect(() => {
    async function setupHighlighter() {
      try {
        const highlighter = await createHighlighterCore({
          langs: [javascript, typescript, tsx, php],
          // @ts-expect-error - Shiki types are incomplete
          themes: [import('tm-themes/themes/github-dark.json')],
          engine: createJavaScriptRegexEngine(),
        })
        setHighlighter(highlighter)
        setIsReady(true)
      }
      catch (error) {
        console.error('Error initializing Shiki highlighter:', error)
      }
    }
    setupHighlighter()
  }, [])

  const contextValue = React.useMemo(() => ({ highlighter, isReady }), [highlighter, isReady])

  if (!isReady) {
    return null
  }

  return <ShikiContext.Provider value={contextValue}>{children}</ShikiContext.Provider>
}

function useShiki() {
  return useContext(ShikiContext)
}

export { ShikiProvider, useShiki }
